@@ -268,9 +268,12 @@ class Cursor(common.DBAPICursor):
         client = self.connection.client
         self._query_id = client.prepareStatement(sql)
         client.executeStatement(self._query_id)
+
+        _logger.info("getting result metadata")
         buffer = client.getResultMetadata(self._query_id)
         buffer = BytesIO(buffer)
         self._query_columns_description = get_query_columns_info(buffer)
+        _logger.info("finished populating metadata")
         return
 
     def cancel(self):
@@ -278,6 +281,7 @@ class Cursor(common.DBAPICursor):
         pass
 
     def _fetch_more(self):
+        _logger.info("fetching batch")
         batch_size = self._arraysize
         self._data = list()
         for i in range(batch_size):
@@ -286,6 +290,7 @@ class Cursor(common.DBAPICursor):
                 return
             self._data.append(row)
 
+        _logger.info("fetched batch of {num}".format(num=len(self._data)))
         return self._data
 
     def _fetch_all(self):
